@@ -216,7 +216,7 @@ def n2sn_change_user(operation):
                                    "check you have the correct "
                                    "permission.") from None
 
-            print("\nSucsesfully added right {} to user \"{}\""
+            print("\nSuccessfully added right {} to user \"{}\""
                   " for instrument {}\n"
                   .format(right.upper(), user['displayName'],
                           inst_config['name'].upper()))
@@ -230,7 +230,7 @@ def n2sn_change_user(operation):
                                    "check you have the correct "
                                    "permission.") from None
 
-            print("\nSucsesfully removed right {} from user \"{}\""
+            print("\nSuccessfully removed right {} from user \"{}\""
                   " for instrument {}\n"
                   .format(right.upper(), user['displayName'],
                           inst_config['name'].upper()))
@@ -252,7 +252,7 @@ def n2sn_change_user(operation):
                                    "check you have the correct "
                                    "permission.") from None
 
-            print("\nSucsesfully removed all users"
+            print("\nSuccessfully removed all users"
                   " for instrument {} with right '{}'\n"
                   .format(inst_config['name'].upper(),
                           right.upper()))
@@ -321,7 +321,8 @@ def n2sn_search_user():
         common_config['server'],
         common_config['group_search'].strip('"'),
         common_config['user_search'].strip('"'),
-        args.surname, args.givenname, args.type
+        args.surname, args.givenname, args.type,
+        ca_certs_file=common_config.get('ldap_ca_cert', None),
     )
 
     print(table)
